<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Hora del Meridiano de Greenwich (Abiyán)',
        'Africa/Accra' => 'Hora del Meridiano de Greenwich (Acra)',
        'Africa/Addis_Ababa' => 'Hora de Africa Oriental (Adís Abeba)',
        'Africa/Algiers' => 'Hora de Europa Central (Argel)',
        'Africa/Asmera' => 'Hora de Africa Oriental (Asmara)',
        'Africa/Bamako' => 'Hora del Meridiano de Greenwich (Bamako)',
        'Africa/Bangui' => 'Hora de Africa Occidental (Bangui)',
        'Africa/Banjul' => 'Hora del Meridiano de Greenwich (Banjul)',
        'Africa/Bissau' => 'Hora del Meridiano de Greenwich (Bissau)',
        'Africa/Blantyre' => 'Hora de Africa Central (Blantyre)',
        'Africa/Brazzaville' => 'Hora de Africa Occidental (Brazzaville)',
        'Africa/Bujumbura' => 'Hora de Africa Central (Bujumbura)',
        'Africa/Cairo' => 'Hora de Europa Oriental (El Cairo)',
        'Africa/Casablanca' => 'Hora de Europa Occidental (Casablanca)',
        'Africa/Ceuta' => 'Hora de Europa Central (Ceuta)',
        'Africa/Conakry' => 'Hora del Meridiano de Greenwich (Conakry)',
        'Africa/Dakar' => 'Hora del Meridiano de Greenwich (Dakar)',
        'Africa/Dar_es_Salaam' => 'Hora de Africa Oriental (Dar es Salaam)',
        'Africa/Djibouti' => 'Hora de Africa Oriental (Yibuti)',
        'Africa/Douala' => 'Hora de Africa Occidental (Duala)',
        'Africa/El_Aaiun' => 'Hora de Europa Occidental (El Aaiun)',
        'Africa/Freetown' => 'Hora del Meridiano de Greenwich (Freetown)',
        'Africa/Gaborone' => 'Hora de Africa Central (Gaborone)',
        'Africa/Harare' => 'Hora de Africa Central (Harare)',
        'Africa/Johannesburg' => 'Hora de Sudafrica (Johannesburgo)',
        'Africa/Juba' => 'Hora de Africa Central (Juba)',
        'Africa/Kampala' => 'Hora de Africa Oriental (Kampala)',
        'Africa/Khartoum' => 'Hora de Africa Central (Jartum)',
        'Africa/Kigali' => 'Hora de Africa Central (Kigali)',
        'Africa/Kinshasa' => 'Hora de Africa Occidental (Kinshasa)',
        'Africa/Lagos' => 'Hora de Africa Occidental (Lagos)',
        'Africa/Libreville' => 'Hora de Africa Occidental (Libreville)',
        'Africa/Lome' => 'Hora del Meridiano de Greenwich (Lome)',
        'Africa/Luanda' => 'Hora de Africa Occidental (Luanda)',
        'Africa/Lubumbashi' => 'Hora de Africa Central (Lubumbashi)',
        'Africa/Lusaka' => 'Hora de Africa Central (Lusaka)',
        'Africa/Malabo' => 'Hora de Africa Occidental (Malabo)',
        'Africa/Maputo' => 'Hora de Africa Central (Maputo)',
        'Africa/Maseru' => 'Hora de Sudafrica (Maseru)',
        'Africa/Mbabane' => 'Hora de Sudafrica (Mbabane)',
        'Africa/Mogadishu' => 'Hora de Africa Oriental (Mogadiscio)',
        'Africa/Monrovia' => 'Hora del Meridiano de Greenwich (Monrovia)',
        'Africa/Nairobi' => 'Hora de Africa Oriental (Nairobi)',
        'Africa/Ndjamena' => 'Hora de Africa Occidental (Ndjamena)',
        'Africa/Niamey' => 'Hora de Africa Occidental (Niamey)',
        'Africa/Nouakchott' => 'Hora del Meridiano de Greenwich (Nouakchott)',
        'Africa/Ouagadougou' => 'Hora del Meridiano de Greenwich (Ouagadougou)',
        'Africa/Porto-Novo' => 'Hora de Africa Occidental (Porto-Novo)',
        'Africa/Sao_Tome' => 'Hora del Meridiano de Greenwich (Sao Tome)',
        'Africa/Tripoli' => 'Hora de Europa Oriental (Tripoli)',
        'Africa/Tunis' => 'Hora de Europa Central (Tunez)',
        'Africa/Windhoek' => 'Hora de Africa Central (Windhoek)',
        'America/Adak' => 'Hora de Hawai-Aleutiano (Adak)',
        'America/Anchorage' => 'Hora de Alaska (Anchorage)',
        'America/Anguilla' => 'Hora del Atlántico (Anguila)',
        'America/Antigua' => 'Hora del Atlántico (Antigua)',
        'America/Araguaina' => 'Hora de Brasilia (Araguaina)',
        'America/Argentina/La_Rioja' => 'Hora de Argentina (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Hora de Argentina (Rio Gallegos)',
        'America/Argentina/Salta' => 'Hora de Argentina (Salta)',
        'America/Argentina/San_Juan' => 'Hora de Argentina (San Juan)',
        'America/Argentina/San_Luis' => 'Hora de Argentina (San Luis)',
        'America/Argentina/Tucuman' => 'Hora de Argentina (Tucuman)',
        'America/Argentina/Ushuaia' => 'Hora de Argentina (Ushuaia)',
        'America/Aruba' => 'Hora del Atlántico (Aruba)',
        'America/Asuncion' => 'Hora de Paraguay (Asuncion)',
        'America/Bahia' => 'Hora de Brasilia (Bahia)',
        'America/Bahia_Banderas' => 'Hora Central (Bahia Banderas)',
        'America/Barbados' => 'Hora del Atlántico (Barbados)',
        'America/Belem' => 'Hora de Brasilia (Belem)',
        'America/Belize' => 'Hora Central (Belice)',
        'America/Blanc-Sablon' => 'Hora del Atlántico (Blanc-Sablon)',
        'America/Boa_Vista' => 'Hora de Amazonas (Boa Vista)',
        'America/Bogota' => 'Hora de Colombia (Bogota)',
        'America/Boise' => 'Hora de la Montaña (Boise)',
        'America/Buenos_Aires' => 'Hora de Argentina (Buenos Aires)',
        'America/Cambridge_Bay' => 'Hora de la Montaña (Cambridge Bay)',
        'America/Campo_Grande' => 'Hora de Amazonas (Campo Grande)',
        'America/Cancun' => 'Hora del Este (Cancun)',
        'America/Caracas' => 'Hora de Venezuela (Caracas)',
        'America/Catamarca' => 'Hora de Argentina (Catamarca)',
        'America/Cayenne' => 'Hora de Guayana Francesa (Cayenne)',
        'America/Cayman' => 'Hora del Este (Cayman)',
        'America/Chicago' => 'Hora Central (Chicago)',
        'America/Chihuahua' => 'Hora Central (Chihuahua)',
        'America/Ciudad_Juarez' => 'Hora de la Montaña (Ciudad Juárez)',
        'America/Coral_Harbour' => 'Hora del Este (Atikokan)',
        'America/Cordoba' => 'Hora de Argentina (Cordoba)',
        'America/Costa_Rica' => 'Hora Central (Costa Rica)',
        'America/Creston' => 'Hora de la Montaña (Creston)',
        'America/Cuiaba' => 'Hora de Amazonas (Cuiaba)',
        'America/Curacao' => 'Hora del Atlántico (Curazao)',
        'America/Danmarkshavn' => 'Hora del Meridiano de Greenwich (Danmarkshavn)',
        'America/Dawson' => 'Yukon Ura (Dawson)',
        'America/Dawson_Creek' => 'Hora de la Montaña (Dawson Creek)',
        'America/Denver' => 'Hora de la Montaña (Denver)',
        'America/Detroit' => 'Hora del Este (Detroit)',
        'America/Dominica' => 'Hora del Atlántico (Dominica)',
        'America/Edmonton' => 'Hora de la Montaña (Edmonton)',
        'America/Eirunepe' => 'Brasil (Eirunepe)',
        'America/El_Salvador' => 'Hora Central (El Salvador)',
        'America/Fort_Nelson' => 'Hora de la Montaña (Fort Nelson)',
        'America/Fortaleza' => 'Hora de Brasilia (Fortaleza)',
        'America/Glace_Bay' => 'Hora del Atlántico (Glace Bay)',
        'America/Godthab' => 'Hora de Groenlandia Occidental (Nuuk)',
        'America/Goose_Bay' => 'Hora del Atlántico (Goose Bay)',
        'America/Grand_Turk' => 'Hora del Este (Grand Turk)',
        'America/Grenada' => 'Hora del Atlántico (Granada)',
        'America/Guadeloupe' => 'Hora del Atlántico (Guadalupe)',
        'America/Guatemala' => 'Hora Central (Guatemala)',
        'America/Guayaquil' => 'Hora de Ecuador (Guayaquil)',
        'America/Guyana' => 'Hora de Guyana',
        'America/Halifax' => 'Hora del Atlántico (Halifax)',
        'America/Havana' => 'Hora de Cuba (La Habana)',
        'America/Hermosillo' => 'Hora del Pacífico Mexicano (Hermosillo)',
        'America/Indiana/Knox' => 'Hora Central (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Hora del Este (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Hora del Este (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Hora Central (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Hora del Este (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Hora del Este (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Hora del Este (Winamac, Indiana)',
        'America/Indianapolis' => 'Hora del Este (Indianapolis)',
        'America/Inuvik' => 'Hora de la Montaña (Inuvik)',
        'America/Iqaluit' => 'Hora del Este (Iqaluit)',
        'America/Jamaica' => 'Hora del Este (Jamaica)',
        'America/Jujuy' => 'Hora de Argentina (Jujuy)',
        'America/Juneau' => 'Hora de Alaska (Juneau)',
        'America/Kentucky/Monticello' => 'Hora del Este (Monticello, Kentucky)',
        'America/Kralendijk' => 'Hora del Atlántico (Kralendijk)',
        'America/La_Paz' => 'Bolivia Time (La Paz)',
        'America/Lima' => 'Hora de Perú (Lima)',
        'America/Los_Angeles' => 'Hora del Pacífico (Los Angeles)',
        'America/Louisville' => 'Hora del Este (Louisville)',
        'America/Lower_Princes' => 'Hora del Atlántico (Lower Prince’s Quarter)',
        'America/Maceio' => 'Hora de Brasilia (Maceio)',
        'America/Managua' => 'Hora Central (Managua)',
        'America/Manaus' => 'Hora de Amazonas (Manaus)',
        'America/Marigot' => 'Hora del Atlántico (Marigot)',
        'America/Martinique' => 'Hora del Atlántico (Martinica)',
        'America/Matamoros' => 'Hora Central (Matamoros)',
        'America/Mazatlan' => 'Hora del Pacífico Mexicano (Mazatlan)',
        'America/Mendoza' => 'Hora de Argentina (Mendoza)',
        'America/Menominee' => 'Hora Central (Menominee)',
        'America/Merida' => 'Hora Central (Merida)',
        'America/Metlakatla' => 'Hora de Alaska (Metlakatla)',
        'America/Mexico_City' => 'Hora Central (Ciudad de Mexico)',
        'America/Miquelon' => 'Hora de San Pedro y Miquelón (Miquelon)',
        'America/Moncton' => 'Hora del Atlántico (Moncton)',
        'America/Monterrey' => 'Hora Central (Monterrey)',
        'America/Montevideo' => 'Hora de Uruguay (Montevideo)',
        'America/Montserrat' => 'Hora del Atlántico (Montserrat)',
        'America/Nassau' => 'Hora del Este (Nassau)',
        'America/New_York' => 'Hora del Este (New York)',
        'America/Nipigon' => 'Hora del Este (Nipigon)',
        'America/Nome' => 'Hora de Alaska (Nome)',
        'America/Noronha' => 'Hora de Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'Hora Central (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'Hora Central (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'Hora Central (New Salem, North Dakota)',
        'America/Ojinaga' => 'Hora Central (Ojinaga)',
        'America/Panama' => 'Hora del Este (Panama)',
        'America/Pangnirtung' => 'Hora del Este (Pangnirtung)',
        'America/Paramaribo' => 'Hora de Surinam (Paramaribo)',
        'America/Phoenix' => 'Hora de la Montaña (Phoenix)',
        'America/Port-au-Prince' => 'Hora del Este (Puerto Príncipe)',
        'America/Port_of_Spain' => 'Hora del Atlántico (Puerto España)',
        'America/Porto_Velho' => 'Hora de Amazonas (Porto Velho)',
        'America/Puerto_Rico' => 'Hora del Atlántico (Puerto Rico)',
        'America/Punta_Arenas' => 'Hora de Chile (Punta Arenas)',
        'America/Rainy_River' => 'Hora Central (Rainy River)',
        'America/Rankin_Inlet' => 'Hora Central (Rankin Inlet)',
        'America/Recife' => 'Hora de Brasilia (Recife)',
        'America/Regina' => 'Hora Central (Regina)',
        'America/Resolute' => 'Hora Central (Resolute)',
        'America/Rio_Branco' => 'Brasil (Rio Branco)',
        'America/Santa_Isabel' => 'Hora Estandar de Verano de México (Santa Isabel)',
        'America/Santarem' => 'Hora de Brasilia (Santarem)',
        'America/Santiago' => 'Hora de Chile (Santiago)',
        'America/Santo_Domingo' => 'Hora del Atlántico (Santo Domingo)',
        'America/Sao_Paulo' => 'Hora de Brasilia (Sao Paulo)',
        'America/Scoresbysund' => 'Hora de Groenlandia (Ittoqqortoormiit)',
        'America/Sitka' => 'Hora de Alaska (Sitka)',
        'America/St_Barthelemy' => 'Hora del Atlántico (San Bartolomé)',
        'America/St_Johns' => 'Hora de Terranova (San Juan de Terranova)',
        'America/St_Kitts' => 'Hora del Atlántico (San Cristobal)',
        'America/St_Lucia' => 'Hora del Atlántico (Santa Lucia)',
        'America/St_Thomas' => 'Hora del Atlántico (Santo Tomas)',
        'America/St_Vincent' => 'Hora del Atlántico (San Vicente)',
        'America/Swift_Current' => 'Hora Central (Swift Current)',
        'America/Tegucigalpa' => 'Hora Central (Tegucigalpa)',
        'America/Thule' => 'Hora del Atlántico (Thule)',
        'America/Thunder_Bay' => 'Hora del Este (Thunder Bay)',
        'America/Tijuana' => 'Hora del Pacífico (Tijuana)',
        'America/Toronto' => 'Hora del Este (Toronto)',
        'America/Tortola' => 'Hora del Atlántico (Tortola)',
        'America/Vancouver' => 'Hora del Pacífico (Vancouver)',
        'America/Whitehorse' => 'Yukon Ura (Whitehorse)',
        'America/Winnipeg' => 'Hora Central (Winnipeg)',
        'America/Yakutat' => 'Hora de Alaska (Yakutat)',
        'America/Yellowknife' => 'Hora de la Montaña (Yellowknife)',
        'Antarctica/Casey' => 'Antártida (Casey)',
        'Antarctica/Davis' => 'Hora de Davis',
        'Antarctica/DumontDUrville' => 'Hora de Dumont-d’Urville',
        'Antarctica/Macquarie' => 'Hora de Australia Oriental (Macquarie)',
        'Antarctica/Mawson' => 'Hora de Mawson',
        'Antarctica/McMurdo' => 'Hora de Nueva Zelanda (McMurdo)',
        'Antarctica/Palmer' => 'Hora de Chile (Palmer)',
        'Antarctica/Rothera' => 'Hora de Rothera',
        'Antarctica/Syowa' => 'Hora de Syowa',
        'Antarctica/Troll' => 'Hora del Meridiano de Greenwich (Troll)',
        'Antarctica/Vostok' => 'Hora de Vostok',
        'Arctic/Longyearbyen' => 'Hora de Europa Central (Longyearbyen)',
        'Asia/Aden' => 'Hora de Arabia (Aden)',
        'Asia/Almaty' => 'Hora de Kazajistán Oriental (Almaty)',
        'Asia/Amman' => 'Hora de Europa Oriental (Amán)',
        'Asia/Anadyr' => 'Rusia (Anadyr)',
        'Asia/Aqtau' => 'Hora de Kazajistán del Oeste (Aktau)',
        'Asia/Aqtobe' => 'Hora de Kazajistán del Oeste (Aktobe)',
        'Asia/Ashgabat' => 'Hora de Turkmenistán (Asjabad)',
        'Asia/Atyrau' => 'Hora de Kazajistán del Oeste (Atyrau)',
        'Asia/Baghdad' => 'Hora de Arabia (Bagdad)',
        'Asia/Bahrain' => 'Hora de Arabia (Baréin)',
        'Asia/Baku' => 'Hora de Azerbaiyán (Baku)',
        'Asia/Bangkok' => 'Hora de Indochina (Bangkok)',
        'Asia/Barnaul' => 'Rusia (Barnaul)',
        'Asia/Beirut' => 'Hora de Europa Oriental (Beirut)',
        'Asia/Bishkek' => 'Hora de Kirguistán (Bishkek)',
        'Asia/Brunei' => 'Hora de Brunei Darussalam',
        'Asia/Calcutta' => 'Hora Estandar de India (Kolkata)',
        'Asia/Chita' => 'Hora de Yakutsk (Chita)',
        'Asia/Choibalsan' => 'Hora de Ulán Bator (Choibalsan)',
        'Asia/Colombo' => 'Hora Estandar de India (Colombo)',
        'Asia/Damascus' => 'Hora de Europa Oriental (Damasco)',
        'Asia/Dhaka' => 'Hora de Bangladesh (Dhaka)',
        'Asia/Dili' => 'Hora de Timor Oriental (Dili)',
        'Asia/Dubai' => 'Hora Estandar del Golfo (Dubai)',
        'Asia/Dushanbe' => 'Hora de Tayikistán (Dusambé)',
        'Asia/Famagusta' => 'Hora de Europa Oriental (Famagusta)',
        'Asia/Gaza' => 'Hora de Europa Oriental (Gaza)',
        'Asia/Hebron' => 'Hora de Europa Oriental (Hebron)',
        'Asia/Hong_Kong' => 'Hora de Hong Kong',
        'Asia/Hovd' => 'Hora de Hovd',
        'Asia/Irkutsk' => 'Hora de Irkutsk',
        'Asia/Jakarta' => 'Hora de Indonesia Occidental (Yakarta)',
        'Asia/Jayapura' => 'Hora de Indonesia Oriental (Jayapura)',
        'Asia/Jerusalem' => 'Hora de Israel (Jerusalem)',
        'Asia/Kabul' => 'Hora de Afganistán (Kabul)',
        'Asia/Kamchatka' => 'Rusia (Kamchatka)',
        'Asia/Karachi' => 'Hora de Pakistán (Karachi)',
        'Asia/Katmandu' => 'Hora de Nepal (Katmandú)',
        'Asia/Khandyga' => 'Hora de Yakutsk (Khandyga)',
        'Asia/Krasnoyarsk' => 'Hora de Krasnoyarsk',
        'Asia/Kuala_Lumpur' => 'Hora de Malasia (Kuala Lumpur)',
        'Asia/Kuching' => 'Hora de Malasia (Kuching)',
        'Asia/Kuwait' => 'Hora de Arabia (Kuwait)',
        'Asia/Macau' => 'Hora de China (Macao)',
        'Asia/Magadan' => 'Hora de Magadan',
        'Asia/Makassar' => 'Hora de Indonesia Central (Macasar)',
        'Asia/Manila' => 'Hora de Filipinas (Manila)',
        'Asia/Muscat' => 'Hora Estandar del Golfo (Mascate)',
        'Asia/Nicosia' => 'Hora de Europa Oriental (Nicosia)',
        'Asia/Novokuznetsk' => 'Hora de Krasnoyarsk (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Hora de Novosibirsk',
        'Asia/Omsk' => 'Hora de Omsk',
        'Asia/Oral' => 'Hora de Kazajistán del Oeste (Oral)',
        'Asia/Phnom_Penh' => 'Hora de Indochina (Phnom Penh)',
        'Asia/Pontianak' => 'Hora de Indonesia Occidental (Pontianak)',
        'Asia/Pyongyang' => 'Hora de Corea (Pionyang)',
        'Asia/Qatar' => 'Hora de Arabia (Catar)',
        'Asia/Qostanay' => 'Hora de Kazajistán Oriental (Kostanái)',
        'Asia/Qyzylorda' => 'Hora de Kazajistán del Oeste (Kyzylorda)',
        'Asia/Rangoon' => 'Hora de Myanmar (Rangún)',
        'Asia/Riyadh' => 'Hora de Arabia (Riad)',
        'Asia/Saigon' => 'Hora de Indochina (Ho Chi Minh)',
        'Asia/Sakhalin' => 'Hora de Sakhalin',
        'Asia/Samarkand' => 'Hora de Uzbekistán (Samarcanda)',
        'Asia/Seoul' => 'Hora de Corea (Seúl)',
        'Asia/Shanghai' => 'Hora de China (Shangái)',
        'Asia/Singapore' => 'Hora Estandar de Singapur',
        'Asia/Srednekolymsk' => 'Hora de Magadan (Srednekolymsk)',
        'Asia/Taipei' => 'Hora de Taipéi (Taipei)',
        'Asia/Tashkent' => 'Hora de Uzbekistán (Taskent)',
        'Asia/Tbilisi' => 'Hora de Georgia (Tiflis)',
        'Asia/Tehran' => 'Hora de Irán (Teherán)',
        'Asia/Thimphu' => 'Hora de Bután (Thimphu)',
        'Asia/Tokyo' => 'Hora de Japón (Tokio)',
        'Asia/Tomsk' => 'Rusia (Tomsk)',
        'Asia/Ulaanbaatar' => 'Hora de Ulán Bator (Ulan Bator)',
        'Asia/Urumqi' => 'China (Urumqi)',
        'Asia/Ust-Nera' => 'Hora de Vladivostok (Ust-Nera)',
        'Asia/Vientiane' => 'Hora de Indochina (Vientiane)',
        'Asia/Vladivostok' => 'Hora de Vladivostok',
        'Asia/Yakutsk' => 'Hora de Yakutsk',
        'Asia/Yekaterinburg' => 'Hora de Ekaterinburgo',
        'Asia/Yerevan' => 'Hora de Armenia (Ereván)',
        'Atlantic/Azores' => 'Hora de las Azores',
        'Atlantic/Bermuda' => 'Hora del Atlántico (Bermuda)',
        'Atlantic/Canary' => 'Hora de Europa Occidental (Canarias)',
        'Atlantic/Cape_Verde' => 'Hora de Cabo Verde',
        'Atlantic/Faeroe' => 'Hora de Europa Occidental (Faroe)',
        'Atlantic/Madeira' => 'Hora de Europa Occidental (Madeira)',
        'Atlantic/Reykjavik' => 'Hora del Meridiano de Greenwich (Reykjavik)',
        'Atlantic/South_Georgia' => 'Hora de Georgia del Sur',
        'Atlantic/St_Helena' => 'Hora del Meridiano de Greenwich (Santa Elena)',
        'Atlantic/Stanley' => 'Hora de Islas Malvinas (Stanley)',
        'Australia/Adelaide' => 'Hora de Australia Central (Adelaida)',
        'Australia/Brisbane' => 'Hora de Australia Oriental (Brisbane)',
        'Australia/Broken_Hill' => 'Hora de Australia Central (Broken Hill)',
        'Australia/Currie' => 'Hora de Australia Oriental (Currie)',
        'Australia/Darwin' => 'Hora de Australia Central (Darwin)',
        'Australia/Eucla' => 'Hora de Australia Central Occidental (Eucla)',
        'Australia/Hobart' => 'Hora de Australia Oriental (Hobart)',
        'Australia/Lindeman' => 'Hora de Australia Oriental (Lindeman)',
        'Australia/Lord_Howe' => 'Hora de Lord Howe',
        'Australia/Melbourne' => 'Hora de Australia Oriental (Melbourne)',
        'Australia/Perth' => 'Hora de Australia Occidental (Perth)',
        'Australia/Sydney' => 'Hora de Australia Oriental (Sidney)',
        'CST6CDT' => 'Hora Central',
        'EST5EDT' => 'Hora del Este',
        'Etc/GMT' => 'Hora del Meridiano de Greenwich',
        'Etc/UTC' => 'Tiqsimuyuntin Tupachisqa Hora',
        'Europe/Amsterdam' => 'Hora de Europa Central (Amsterdam)',
        'Europe/Andorra' => 'Hora de Europa Central (Andorra)',
        'Europe/Astrakhan' => 'Hora de Moscú (Astrakhan)',
        'Europe/Athens' => 'Hora de Europa Oriental (Athens)',
        'Europe/Belgrade' => 'Hora de Europa Central (Belgrade)',
        'Europe/Berlin' => 'Hora de Europa Central (Berlin)',
        'Europe/Bratislava' => 'Hora de Europa Central (Bratislava)',
        'Europe/Brussels' => 'Hora de Europa Central (Bruselas)',
        'Europe/Bucharest' => 'Hora de Europa Oriental (Bucarest)',
        'Europe/Budapest' => 'Hora de Europa Central (Budapest)',
        'Europe/Busingen' => 'Hora de Europa Central (Busingen)',
        'Europe/Chisinau' => 'Hora de Europa Oriental (Chisinau)',
        'Europe/Copenhagen' => 'Hora de Europa Central (Copenhague)',
        'Europe/Dublin' => 'Hora del Meridiano de Greenwich (Dublin)',
        'Europe/Gibraltar' => 'Hora de Europa Central (Gibraltar)',
        'Europe/Guernsey' => 'Hora del Meridiano de Greenwich (Guernsey)',
        'Europe/Helsinki' => 'Hora de Europa Oriental (Helsinki)',
        'Europe/Isle_of_Man' => 'Hora del Meridiano de Greenwich (Isla de Man)',
        'Europe/Istanbul' => 'Turquía (Estambul)',
        'Europe/Jersey' => 'Hora del Meridiano de Greenwich (Jersey)',
        'Europe/Kaliningrad' => 'Hora de Europa Oriental (Kaliningrado)',
        'Europe/Kiev' => 'Hora de Europa Oriental (Kiev)',
        'Europe/Kirov' => 'Rusia (Kirov)',
        'Europe/Lisbon' => 'Hora de Europa Occidental (Lisboa)',
        'Europe/Ljubljana' => 'Hora de Europa Central (Liubliana)',
        'Europe/London' => 'Hora del Meridiano de Greenwich (Londres)',
        'Europe/Luxembourg' => 'Hora de Europa Central (Luxemburgo)',
        'Europe/Madrid' => 'Hora de Europa Central (Madrid)',
        'Europe/Malta' => 'Hora de Europa Central (Malta)',
        'Europe/Mariehamn' => 'Hora de Europa Oriental (Mariehamn)',
        'Europe/Minsk' => 'Hora de Moscú (Minsk)',
        'Europe/Monaco' => 'Hora de Europa Central (Monaco)',
        'Europe/Moscow' => 'Hora de Moscú',
        'Europe/Oslo' => 'Hora de Europa Central (Oslo)',
        'Europe/Paris' => 'Hora de Europa Central (Paris)',
        'Europe/Podgorica' => 'Hora de Europa Central (Podgorica)',
        'Europe/Prague' => 'Hora de Europa Central (Praga)',
        'Europe/Riga' => 'Hora de Europa Oriental (Riga)',
        'Europe/Rome' => 'Hora de Europa Central (Roma)',
        'Europe/Samara' => 'Rusia (Samara)',
        'Europe/San_Marino' => 'Hora de Europa Central (San Marino)',
        'Europe/Sarajevo' => 'Hora de Europa Central (Sarajevo)',
        'Europe/Saratov' => 'Hora de Moscú (Saratov)',
        'Europe/Simferopol' => 'Hora de Moscú (Simferopol)',
        'Europe/Skopje' => 'Hora de Europa Central (Skopje)',
        'Europe/Sofia' => 'Hora de Europa Oriental (Sofia)',
        'Europe/Stockholm' => 'Hora de Europa Central (Estocolmo)',
        'Europe/Tallinn' => 'Hora de Europa Oriental (Tallinn)',
        'Europe/Tirane' => 'Hora de Europa Central (Tirana)',
        'Europe/Ulyanovsk' => 'Hora de Moscú (Ulyanovsk)',
        'Europe/Uzhgorod' => 'Hora de Europa Oriental (Uzhgorod)',
        'Europe/Vaduz' => 'Hora de Europa Central (Vaduz)',
        'Europe/Vatican' => 'Hora de Europa Central (El Vaticano)',
        'Europe/Vienna' => 'Hora de Europa Central (Viena)',
        'Europe/Vilnius' => 'Hora de Europa Oriental (Vilnius)',
        'Europe/Volgograd' => 'Hora de Volgogrado',
        'Europe/Warsaw' => 'Hora de Europa Central (Varsovia)',
        'Europe/Zagreb' => 'Hora de Europa Central (Zagreb)',
        'Europe/Zaporozhye' => 'Hora de Europa Oriental (Zaporozhye)',
        'Europe/Zurich' => 'Hora de Europa Central (Zurich)',
        'Indian/Antananarivo' => 'Hora de Africa Oriental (Antananarivo)',
        'Indian/Chagos' => 'Hora del Oceano Índico (Chagos)',
        'Indian/Christmas' => 'Hora de Isla Christmas',
        'Indian/Cocos' => 'Hora de Islas Cocos',
        'Indian/Comoro' => 'Hora de Africa Oriental (Comoro)',
        'Indian/Kerguelen' => 'Hora Francés meridional y antártico (Kerguelen)',
        'Indian/Mahe' => 'Hora de Seychelles (Mahe)',
        'Indian/Maldives' => 'Hora de Maldivas',
        'Indian/Mauritius' => 'Hora de Mauricio (Mauritius)',
        'Indian/Mayotte' => 'Hora de Africa Oriental (Mayotte)',
        'Indian/Reunion' => 'Hora de Réunion (Reunion)',
        'MST7MDT' => 'Hora de la Montaña',
        'PST8PDT' => 'Hora del Pacífico',
        'Pacific/Apia' => 'Hora de Apia',
        'Pacific/Auckland' => 'Hora de Nueva Zelanda (Auckland)',
        'Pacific/Bougainville' => 'Hora de Papua Nueva Guinea (Bougainville)',
        'Pacific/Chatham' => 'Hora de Chatham',
        'Pacific/Easter' => 'Hora de Isla de Pascua (Easter)',
        'Pacific/Efate' => 'Hora de Vanuatu (Efate)',
        'Pacific/Enderbury' => 'Hora de Islas Phoenix (Enderbury)',
        'Pacific/Fakaofo' => 'Hora de Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'Hora de Fiji',
        'Pacific/Funafuti' => 'Hora de Tuvalu (Funafuti)',
        'Pacific/Galapagos' => 'Hora de Islas Galápagos (Galapagos)',
        'Pacific/Gambier' => 'Hora de Gambier',
        'Pacific/Guadalcanal' => 'Hora de Islas Salomón (Guadalcanal)',
        'Pacific/Guam' => 'Hora Estandar de Chamorro (Guam)',
        'Pacific/Honolulu' => 'Hora de Hawai-Aleutiano (Honolulu)',
        'Pacific/Johnston' => 'Hora de Hawai-Aleutiano (Johnston)',
        'Pacific/Kiritimati' => 'Hora de Espóradas Ecuatoriales (Kiritimati)',
        'Pacific/Kosrae' => 'Hora de Kosrae',
        'Pacific/Kwajalein' => 'Hora de Islas Marshall (Kwajalein)',
        'Pacific/Majuro' => 'Hora de Islas Marshall (Majuro)',
        'Pacific/Marquesas' => 'Hora de Marquesas',
        'Pacific/Midway' => 'Hora de Samoa (Midway)',
        'Pacific/Nauru' => 'Hora de Nauru',
        'Pacific/Niue' => 'Hora de Niue',
        'Pacific/Norfolk' => 'Hora de la Isla Norfolk',
        'Pacific/Noumea' => 'Hora de Nueva Caledonia (Noumea)',
        'Pacific/Pago_Pago' => 'Hora de Samoa (Pago Pago)',
        'Pacific/Palau' => 'Hora de Palau',
        'Pacific/Pitcairn' => 'Hora de Pitcairn',
        'Pacific/Ponape' => 'Hora de Pohnpei',
        'Pacific/Port_Moresby' => 'Hora de Papua Nueva Guinea (Port Moresby)',
        'Pacific/Rarotonga' => 'Hora de Islas Cook (Rarotonga)',
        'Pacific/Saipan' => 'Hora Estandar de Chamorro (Saipan)',
        'Pacific/Tahiti' => 'Hora de Tahiti',
        'Pacific/Tarawa' => 'Hora de Islas Gilbert (Tarawa)',
        'Pacific/Tongatapu' => 'Hora de Tonga (Tongatapu)',
        'Pacific/Truk' => 'Hora de Chuuk',
        'Pacific/Wake' => 'Hora de Isla Wake',
        'Pacific/Wallis' => 'Hora de Wallis y Futuna',
    ],
    'Meta' => [
    ],
];
